@@ -1973,7 +1973,7 @@ struct exarg
     void	*cookie;	// argument for getline()
 #ifdef FEAT_EVAL
     cstack_T	*cstack;	// condition stack for ":if" etc.
-    class_T	*class;		// Name of class being defined. Used by :class
+    class_T	*ea_class;		// Name of class being defined. Used by :class
 				// and :enum commands.
 #endif
 };
