@@ -915,7 +915,7 @@ op_format(
     }
 }
 
-#if defined(FEAT_EVAL) || defined(PROTO)
+#if defined(FEAT_EVAL)
 /*
  * Implementation of the format operator 'gq' for when using 'formatexpr'.
  */
@@ -938,8 +938,8 @@ fex_format(
     long	count,
     int		c)	// character to be inserted
 {
-    int		use_sandbox = was_set_insecurely((char_u *)"formatexpr",
-								   OPT_LOCAL);
+    int		use_sandbox = was_set_insecurely(curwin,
+					    (char_u *)"formatexpr", OPT_LOCAL);
     int		r;
     char_u	*fex;
     sctx_T	save_sctx = current_sctx;
